function [S,kompletniparametry,y]=tvarVspozadim(param,data)
%[S,kompletniparametry,y]=tvarVspozadim(param,data)
%Pocita sumu ctvercu odchylek Voigtova profilu definovaneho parametry "param" 
% od merenych dat ("data"). Prvni sloupec matice "data" jsou x-ove
% souradnice merenych dat, druhy sloupec jsou y-ove souradnice. 
%Vektor "param" obsahuje tri cisla: pozici centra cary, parametr Gaussova
% rozsireni (sigma) a parametr Lorentzova rozsireni (gama). 
%Funkce tvarVspozadim.m si sama najde optimalni hodnoty pozadi a intenzity cary takove, 
% aby suma ctvercu odchylek byla minimalni. 
%
%"S" je suma ctvercu odchylek 
%"kompletniparametry" je vektor parametru "param" s dodanou velikosti cary a urovni pozadi. 
%"y" je vysledny Voigtuv profil vynasobeny velikosti cary a posunuty o pozadi. 

x=data(:,1);
y0=voigt(x-param(1),param(2),param(3)); %Voigtuv profil s jednotkovym integralem a bez pozadi 
sd=sum(data(:,2));
sdv=sum(data(:,2).*y0); 
sv=sum(y0);
svv=sum(y0.^2); 
N=length(y0);

a=(N*sdv-sv*sd)/(N*svv-sv^2); %Velikost cary 
p=(svv*sd-sv*sdv)/(N*svv-sv^2); %Uroven pozadi 

y=a*y0+p; %Voigtuv profil
S=sum((y-data(:,2)).^2); %Suma ctvercu odchylek 
kompletniparametry=[param a p]; %Vsech 5 parametru: pozice - sigma - gama - velikost - pozadi 
